@@ -5,7 +5,7 @@ Let's set up a site in which we manage a couple of objects::
 
   >>> herd = Herd()
   >>> getRootFolder()['herd'] = herd
-  >>> from zope.app.component.hooks import setSite
+  >>> from zope.site.hooks import setSite
   >>> setSite(herd)
 
 Now we add some indexable objects to the site::
@@ -16,7 +16,7 @@ Now we add some indexable objects to the site::
 
 Let's query the set index::
 
-  >>> from zope.app.catalog.interfaces import ICatalog
+  >>> from zope.catalog.interfaces import ICatalog
   >>> from zope.component import getUtility, queryUtility
   >>> catalog = getUtility(ICatalog)
   >>> def sortedResults(catalog, **kw):
@@ -29,15 +29,15 @@ Let's query the set index::
   ['Alpha', 'Beta']
   >>> sortedResults(catalog, features={'any_of': ['friendly']})
   ['Beta', 'Gamma']
-  
+
 Nuke the catalog and intids in the end, so as not to confuse
 other tests::
 
   >>> sm = herd.getSiteManager()
-  >>> from zope.app.catalog.interfaces import ICatalog
+  >>> from zope.catalog.interfaces import ICatalog
   >>> sm.unregisterUtility(catalog, provided=ICatalog)
   True
-  >>> from zope.app.intid.interfaces import IIntIds
+  >>> from zope.intid.interfaces import IIntIds
   >>> from zope import component
   >>> intids = component.getUtility(IIntIds)
   >>> sm.unregisterUtility(intids, provided=IIntIds)
@@ -47,7 +47,6 @@ Unfortunately ftests don't have good isolation from each other yet.
 """
 
 from zope.interface import Interface, Attribute
-from zope import schema
 
 import grok
 from grok import index
@@ -57,7 +56,7 @@ class Herd(grok.Container, grok.Application):
 
 class IMammoth(Interface):
     features = Attribute('Features')
-    
+
 class MammothIndexes(grok.Indexes):
     grok.site(Herd)
     grok.context(IMammoth)
@@ -70,4 +69,4 @@ class Mammoth(grok.Model):
     def __init__(self, name, features):
         self.name = name
         self.features = features
-    
+
