@@ -3,10 +3,10 @@
 After grokking a module that defines an application, the application factory is
 available as a utility::
 
-    >>> grok.grok(__name__)
+    >>> grok.testing.grok(__name__)
     >>> import zope.component
-    >>> import grok.interfaces
-    >>> calendar_app = zope.component.getUtility(grok.interfaces.IApplication,
+    >>> import grokcore.site.interfaces
+    >>> calendar_app = zope.component.getUtility(grokcore.site.interfaces.IApplication,
     ...                                          name='grok.tests.application.application.Calendar')
     >>> calendar_app
     <class 'grok.tests.application.application.Calendar'>
